@@ -3,12 +3,11 @@ import logging
 from copy import copy
 
 import pika
-from django.views.debug import ExceptionReporter
 from pika import credentials
 
 from .filters import FieldFilter
 from .formatters import JSONFormatter
-
+from .compat import ExceptionReporter
 
 class RabbitMQHandler(logging.Handler):
     """
@@ -16,14 +15,16 @@ class RabbitMQHandler(logging.Handler):
     Inspired by: https://github.com/ziXiong/MQHandler
     """
     def __init__(self, level=logging.NOTSET, formatter=None,
-                 host='localhost', port=5672, connection_params=None,
-                 username=None, password=None,
-                 exchange='log', declare_exchange=False,
-                 routing_key_format="{name}.{level}",
-                 routing_key_formatter=None,
-                 close_after_emit=False,
-                 fields=None, fields_under_root=True, message_headers=None,
-                 record_fields=None, exclude_record_fields=None):
+        host='localhost', port=5672, connection_params=None,
+        username=None, password=None,
+        exchange='log', declare_exchange=False,
+        routing_key_format="{name}.{level}",
+        routing_key_formatter=None,
+        close_after_emit=False,
+        fields=None, fields_under_root=True, message_headers=None,
+        record_fields=None, exclude_record_fields=None,
+        heartbeat=60,
+        content_type='text/plain'):
         # Initialize the handler.
         #
         # :param level:                 Logs level.
@@ -42,8 +43,11 @@ class RabbitMQHandler(logging.Handler):
         # :param close_after_emit:      Close connection after emit the record?
         # :param fields:                Send these fields as part of all logs.
         # :param fields_under_root:     Merge the fields in the root object.
-        # :record_fields                A set of attributes that should be preserved from the record object.
-        # :exclude_record_fields        A set of attributes that should be ignored from the record object.
+        # :record_fields:               A set of attributes that should be preserved from the record object.
+        # :exclude_record_fields:       A set of attributes that should be ignored from the record object.
+        # :heartbeat:                   Lower bound for heartbeat timeout.
+        # :content_type:                The format of the message sent to the queue.
+
         super(RabbitMQHandler, self).__init__(level=level)
 
         # Important instances/properties.
@@ -59,13 +63,14 @@ class RabbitMQHandler(logging.Handler):
         # @see: http://pika.readthedocs.io/en/0.10.0/modules/parameters.html#pika.connection.ConnectionParameters
         conn_params = connection_params if isinstance(connection_params, dict) else {}
         self.connection_params = conn_params.copy()
-        self.connection_params.update(dict(host=host, port=port, heartbeat_interval=0))
+        self.connection_params.update(dict(host=host, port=port, heartbeat=heartbeat, blocked_connection_timeout=150))
 
         if username and password:
             self.connection_params['credentials'] = credentials.PlainCredentials(username, password)
 
         # Extra params for message publication
         self.message_headers = message_headers
+        self.content_type = content_type
 
         # Save routing-key formatter.
         self.routing_key_formatter = routing_key_formatter
@@ -148,8 +153,11 @@ class RabbitMQHandler(logging.Handler):
                 else:
                     exc_info = (None, record.getMessage(), None)
 
-                reporter = ExceptionReporter(record.request, is_email=False, *exc_info)
-                no_exc_record.traceback = reporter.get_traceback_text()
+                # Get a text representation of the exception.
+                if ExceptionReporter:
+                    reporter = ExceptionReporter(record.request, is_email=False, *exc_info)
+                    no_exc_record.traceback = reporter.get_traceback_text()
+
                 formatted = self.format(no_exc_record)
             else:
                 formatted = self.format(record)
@@ -160,7 +168,8 @@ class RabbitMQHandler(logging.Handler):
                 body=formatted,
                 properties=pika.BasicProperties(
                     delivery_mode=2,
-                    headers=self.message_headers
+                    headers=self.message_headers,
+                    content_type=self.content_type
                 )
             )
 
